@@ -82,9 +82,14 @@ proc tkviewpr_raw {prid prtext} {
     
     view_menu_bar $prid
     
+    .mframe.help.m add command -label "Cut, Copy, Paste Operations" \
+            -command "helpMsg Cut_Copy_Paste"
+    .mframe.help.m add separator
     .mframe.help.m add command -label "View Configuration Variables" \
         -command "helpMsg TkGnats_Variables"
     .mframe.help.m add separator
+    .mframe.help.m add command -label "Changes" \
+            -command "helpMsg Changes"
     .mframe.help.m add command -label "About" \
             -command "helpMsg TkGnats_About"
     
@@ -97,11 +102,13 @@ proc tkviewpr_raw {prid prtext} {
             -font $TkGnats(textfont) \
             -yscrollcommand ".sb set" \
             -height 30 -width 80 -relief sunken -padx 4 -insertwidth 1 \
-            -insertofftime 400 -borderwidth 2
+            -insertofftime 400 -borderwidth 2 -background [.action.close cget -background]
     pack .text -side right -expand true -fill both
+    set_focus_style .text
 
     .text insert 1.0 $prtext
     .text configure -state disabled
+    bind .text <3> "clipboard_post .text %X %Y"
     
     wm title . "TkGnats - View Problem Report: $prid"
     wm iconbitmap . @$TkGnats(lib)/tkeditpr.xbm
@@ -137,7 +144,7 @@ proc headingMsg {a} {
 
 proc editSelection_cmd {prid} {
     global TkGnats
-    . configure -cursor watch
+    busy_cursor set
     update idletasks
     headingMsg "Please Wait..."
     TkGnats_exec $TkGnats(WISHPATH) $TkGnats(lib)/tkeditpr.tcl -prid $prid \
@@ -147,27 +154,33 @@ proc editSelection_cmd {prid} {
             -responsible $TkGnats(ResponsibleFile) &
     schedule_reap
     after 4000
-    . configure -cursor left_ptr
+    busy_cursor clear
     close_report
 }
     
 proc view_menu_bar {prid} {
-    global flds
+    global TkGnats flds
     frame      .mframe -borderwidth 1 -relief raised
     pack       .mframe -side top -fill x
 
     menubutton .mframe.file -text "File" -menu .mframe.file.m -underline 0
     menu       .mframe.file.m
     .mframe.file.m add command -label "Edit Report..." -command "editSelection_cmd $prid"
+    if {! $TkGnats(edit_authorized)} {
+        .mframe.file.m entryconfigure "Edit Report..." -state disabled
+    }
     .mframe.file.m add command -label "Send Email..."  -command \
-            "email_originator [list [ftrim $flds(Reply-To)]] \
-            [list [ftrim $flds(>Responsible)]] [list [ftrim $flds(From)]] \
+            "email_originator [list [ftrim $flds(X-GNATS-Notify)]] \
+            [list [ftrim $flds(>Responsible)]] [list [ftrim $flds(Reply-To)]] \
             [ftrim $flds(>Category)]/$prid [list [ftrim $flds(>Synopsis)]]"
     .mframe.file.m add separator
     .mframe.file.m add command -label "Close"          -command close_report
     
     menubutton .mframe.edit -text "Edit" -menu .mframe.edit.m -underline 0
     menu       .mframe.edit.m
+    .mframe.edit.m     configure -disabledforeground [.mframe.edit.m cget -foreground]
+    .mframe.edit.m add command -label "Use right mouse button for Cut/Copy/Paste" -state disabled
+    .mframe.edit.m add separator
     .mframe.edit.m add command -label "Fonts..." -command "edit_fonts"
     
     pack .mframe.file .mframe.edit -side left
@@ -184,8 +197,8 @@ proc view_action_bar {prid} {
     button .action.close -borderwidth 1 -text "Close"   -command close_report
     button .action.edit  -borderwidth 1 -text "Edit..." -command "editSelection_cmd $prid"
     button .action.email -borderwidth 1 -text "Send Email..." \
-            -command "email_originator [list [ftrim $flds(Reply-To)]] \
-            [list [ftrim $flds(>Responsible)]] [list [ftrim $flds(From)]] \
+            -command "email_originator [list [ftrim $flds(X-GNATS-Notify)]] \
+            [list [ftrim $flds(>Responsible)]] [list [ftrim $flds(Reply-To)]] \
             [ftrim $flds(>Category)]/$prid [list [ftrim $flds(>Synopsis)]]"
 ####       [lrange [split [ftrim $flds(>Originator)]] 0 0]
     
@@ -214,17 +227,17 @@ proc tkviewpr_formatted {prid} {
         >How-To-Repeat
         >Environment
         >Organization
+        >Fix
         >Audit-Trail
         >Unformatted
-        >Fix
         >Release-Note
     }
     
     set current_multi_text ""
     
-    # Get the maximum width of the value fields for the bagged_radiobar
+    # Get the maximum width of the value fields for the listboxes and radio (enumerated) fields
     set Tkviewpr(value_width) 0
-    foreach tag [concat >Category >Responsible $Tkviewpr(radioflds)] {
+    foreach tag [concat >Category >Submitter-Id >Responsible $Tkviewpr(radioflds)] {
         set f [ftrim $flds($tag)]
         if {[string length $f] > $Tkviewpr(value_width)} {
             set Tkviewpr(value_width) [string length $f]
@@ -232,9 +245,20 @@ proc tkviewpr_formatted {prid} {
     }
     incr Tkviewpr(value_width)
 
+    # Get the maximum width of the value fields for the date fields
+    set Tkviewpr(datevalue_width) 0
+    set flist {>Last-Modified >Arrival-Date >Closed-Date}
+    foreach tag $flist {
+        set f [ftrim $flds($tag)]
+        if {[string length $f] > $Tkviewpr(datevalue_width)} {
+            set Tkviewpr(datevalue_width) [string length $f]
+        }
+    }
+    incr Tkviewpr(datevalue_width)
+
     # Get the maximum width of the value fields for the readonly_singletext fields
     set Tkviewpr(singletextvalue_width) 0
-    set flist {>Originator Reply-To >Release >Synopsis >Last-Modified >Arrival-Date >Closed-Date}
+    set flist {>Originator X-GNATS-Notify >Release >Synopsis}
     if {$TkGnats(ReleaseBased)} {
         lappend flist >Keywords >$TkGnats(Quarter) >Date-Required
     }
@@ -253,6 +277,9 @@ proc tkviewpr_formatted {prid} {
     .mframe.help.m add command -label "Overview" \
             -command "helpMsg View_Overview"
     .mframe.help.m add separator
+    .mframe.help.m add command -label "Cut, Copy, Paste Operations" \
+            -command "helpMsg Cut_Copy_Paste"
+    .mframe.help.m add separator
     .mframe.help.m add command -label "Field Definitions" \
             -command "helpMsg Field_Definitions"
     .mframe.help.m add separator
@@ -262,61 +289,57 @@ proc tkviewpr_formatted {prid} {
     .mframe.help.m add command -label "View Configuration Variables" \
         -command "helpMsg TkGnats_Variables"
     .mframe.help.m add separator
+    .mframe.help.m add command -label "Changes" \
+            -command "helpMsg Changes"
     .mframe.help.m add command -label "About" \
             -command "helpMsg TkGnats_About"
     
     view_action_bar $prid
-    
-    readonly_singletext Arrival-Date  [ftrim $flds(>Arrival-Date)]  14 \
-            $Tkviewpr(singletextvalue_width)
-    readonly_singletext Last-Modified [ftrim $flds(>Last-Modified)] 14 \
-            $Tkviewpr(singletextvalue_width)
-    readonly_singletext Closed-Date   [ftrim $flds(>Closed-Date)]   14 \
-            $Tkviewpr(singletextvalue_width)
-    readonly_singletext Class         [ftrim $flds(>Class)] 14 \
-            $Tkviewpr(value_width)
-    readonly_singletext State         [ftrim $flds(>State)] 14 \
-            $Tkviewpr(value_width)
-    readonly_singletext Priority      [ftrim $flds(>Priority)] 14 \
-            $Tkviewpr(value_width)
-    readonly_singletext Severity      [ftrim $flds(>Severity)] 14 \
-            $Tkviewpr(value_width)
-    readonly_singletext Confidential  [ftrim $flds(>Confidential)] 14 \
-            $Tkviewpr(value_width)
-    readonly_singletext Category      [ftrim $flds(>Category)] 14 \
-            $Tkviewpr(value_width)
-    readonly_singletext Submitter-Id  [ftrim $flds(>Submitter-Id)] 14 \
-            $Tkviewpr(value_width)
-    readonly_singletext Responsible   [ftrim $flds(>Responsible)] 14 \
-            $Tkviewpr(value_width)
-    readonly_singletext Originator    [ftrim $flds(>Originator)]  14 \
-            $Tkviewpr(singletextvalue_width)
-    readonly_singletext Reply-To      [ftrim $flds(Reply-To)]  14 \
-            $Tkviewpr(singletextvalue_width)
-    readonly_singletext Release       [ftrim $flds(>Release)] 14 \
-            $Tkviewpr(singletextvalue_width)
-    readonly_singletext Synopsis      [ftrim $flds(>Synopsis)] 14 \
-            $Tkviewpr(singletextvalue_width)
 
+    set flist [list Arrival-Date Last-Modified Closed-Date Class State Priority Severity Confidential Category Submitter-Id Responsible Originator X-GNATS-Notify Release Synopsis]
     if {$TkGnats(ReleaseBased)} {
-	readonly_singletext Keywords          [ftrim $flds(>Keywords)] 14 \
-		$Tkviewpr(singletextvalue_width)
-	readonly_singletext $TkGnats(Quarter) [ftrim $flds(>$TkGnats(Quarter))] 14 \
-		$Tkviewpr(singletextvalue_width)
-	readonly_singletext Date-Required     [ftrim $flds(>Date-Required)] 14 \
-		$Tkviewpr(singletextvalue_width)
+        lappend flist  Keywords $TkGnats(Quarter) Date-Required
+    }
+    
+    foreach f $flist {
+        if {[check_suppressed_field $f] == 1} {
+            continue
+        }
+	#set tmptag [get_field_alias $f]
+        switch $f {
+            Class -
+            State -
+            Priority -
+            Severity -
+            Confidential -
+            Category -
+            Submitter-Id -
+            Responsible {
+                readonly_singletext $f [ftrim $flds(>$f)] 14 $Tkviewpr(value_width)
+            }
+            Arrival-Date -
+            Last-Modified -
+            Closed-Date {
+                readonly_singletext $f [ftrim $flds(>$f)] 14 $Tkviewpr(datevalue_width)
+            }
+            X-GNATS-Notify {
+                readonly_singletext $f [ftrim $flds($f)]  14 $Tkviewpr(singletextvalue_width)
+            }
+            default {
+                readonly_singletext $f [ftrim $flds(>$f)] 14 $Tkviewpr(singletextvalue_width)
+            }
+        }
     }
     
     make_txt_mb $Tkviewpr(multitextflds)
     destroy .mb.insert
-    .multiline.text configure -state disabled -highlightthickness 0 \
-            -background $TkGnats(mtextbackground) -height 16
+    .multiline.text configure -height 16
     bind multiline.text <Enter> ""
 
     wm title . "TkGnats - [lindex $TkGnats(ServerInfo) 0] - View Problem Report: [ftrim $flds(>Category)]/[ftrim $flds(>Number)]"
     wm iconbitmap . @$TkGnats(lib)/tkeditpr.xbm
     wm iconname   . "$TkGnats(LogName)'s tkviewpr [ftrim $flds(>Number)]"
-    switch_txt ">Description" $Tkviewpr(multitextflds)
+    switch_txt $TkGnats(first_multitext) $Tkviewpr(multitextflds)
 }
 
 set prid    ""
@@ -328,12 +351,12 @@ foreach f { tkpr_library.tcl tkprhelp.tcl tkprfont.tcl } {
     source $TkGnats(lib)/$f
 }
 
-# If TkGnats(GNATS_ACCESS_METHOD) != "socket" then this does nothing
-if {[open_socket_gnatsd 1] == "-1"} {
+if {[get_gnats_config] == "-1"} {
     exit
 }
 
-if {[get_gnats_config] == "-1"} {
+# If TkGnats(GNATS_ACCESS_METHOD) != "socket" then this does nothing
+if {[open_socket_gnatsd 1] == "-1"} {
     exit
 }
 
@@ -349,7 +372,11 @@ if {"$prid" == ""} {
 
 # load the report fields
 
-set prtxt [get_pr_full_text $prid]
+set  prtxt [get_pr_full_text $prid]
+if {$prtxt == "-1"} {
+            $msg "error" 0 "OK"
+    exit
+}
 parsepr_txt  $prtxt flds
 load_field_defaults flds
 
